mobspy.parameter_scripts package — MobsPy 2.2 documentation

# mobspy.parameter_scripts package

## Submodules

## mobspy.parameter_scripts.parameter_reader module

This module is responsible for processing the parameters given to MobsPy before starting the simulation

mobspy.parameter_scripts.parameter_reader.parameter_process(params)

mobspy.parameter_scripts.parameter_reader.read_json(json_file_name)

  Reads json file

  Parameters:

    plot_json_filename – json file name

  Raises:

    simlog.error – If the file was not able to be read

  Returns:

    plot parameter dictionary

## mobspy.parameter_scripts.parametric_sweeps module

mobspy.parameter_scripts.parametric_sweeps.assign_values_to_model(parameter_name, parameter_value, models, locations)

mobspy.parameter_scripts.parametric_sweeps.generate_all_sbml_models(model_parameters, list_of_models)

mobspy.parameter_scripts.parametric_sweeps.unite_parameter_dictionaries(dict_1, dict_2)

## Module contents